@@ -1,7 +1,11 @@
 import os
 
-def path_maker(path_list,relative_path=''):
-    p = os.path.abspath(os.path.join(os.getcwd(),relative_path))
+def path_maker(path_list=[],relative_path='.',start_path=None):
+    '''
+    start_path=None=>os.getcwd()
+    '''
+    start_path = os.getcwd() if start_path==None else start_path
+    p = os.path.abspath(os.path.join(start_path,relative_path))
     for i in path_list:
         p += '/'+str(i)
         if not os.path.exists(p):
